options = (
    (
        "sentry-dsn",
        {
            "type": "string",
            "default": "",
            "help": "Sentry DSN (eg. https://public_key:secret_key@sentry.local/project_id?timeout=10 )",  # noqa: E501
            "group": "sentry",
            "level": 5,
        },
    ),
    (
        "sentry-public-dsn",
        {
            "type": "string",
            "default": "",
            "help": "Sentry Public DSN (eg. https://token@sentry.local/project_id )",
            "group": "sentry",
            "level": 5,
        },
    ),
    (
        "sentry-log-level",
        {
            "type": "choice",
            "choices": ("error", "critical"),
            "default": None,
            "help": "emit Sentry event when logging exception with choosen log level (disabled by default)",  # noqa: E501
            "group": "sentry",
            "level": 5,
        },
    ),
    (
        "sentry-environment",
        {
            "type": "string",
            "default": None,
            "help": "Sentry Application Environment (eg: prod, preprod, demo)",
            "group": "sentry",
            "level": 5,
        },
    ),
)



import logging
import optparse

import sentry_sdk
from sentry_sdk.integrations.logging import LoggingIntegration

try:
    import pyramid  # noqa
except ImportError:
    HAS_PYRAMID = False
else:
    HAS_PYRAMID = True
    from sentry_sdk.integrations.pyramid import PyramidIntegration


def init_sdk(cwconfig):
    """Initialize `sentry_sdk` from cubicweb configuration."""
    try:
        dsn = cwconfig["sentry-dsn"]
    except (optparse.OptionError, KeyError):
        return
    if not dsn:
        return
    release = cwconfig.cube_version(cwconfig.cubes()[0])
    log_level = cwconfig["sentry-log-level"]
    integrations = []
    if HAS_PYRAMID:
        integrations.append(PyramidIntegration())
    if log_level is not None:
        integrations.append(
            LoggingIntegration(
                level=logging.DEBUG,  # Capture debug and above as breadcrumbs
                event_level=log_level.upper(),
            )
        )
    sentry_sdk.init(
        dsn=dsn,
        release=release,
        integrations=integrations,
        environment=cwconfig["sentry-environment"],
    )
    return sentry_sdk



# pylint: disable=W0622
"""cubicweb-sentry application packaging information"""

modname = "sentry"
distname = "cubicweb-sentry"

numversion = (0, 8, 2)
version = ".".join(str(num) for num in numversion)

license = "LGPL"
author = "LOGILAB S.A. (Paris, FRANCE)"
author_email = "contact@logilab.fr"
description = "support for Sentry (getsentry.com)"
web = "https://forge.extranet.logilab.fr/cubicweb/cubes/%s" % distname

classifiers = [
    "Environment :: Web Environment",
    "Framework :: CubicWeb",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3 :: Only",
    "Programming Language :: JavaScript",
]

__depends__ = {"cubicweb": ">= 3.38.9, < 3.39.0", "sentry-sdk": "<1.26.0"}
__recommends__ = {}
